@@ -19,7 +19,7 @@
   packageStartupMessage("**          Toolkit for Topological Data Analysis")
   packageStartupMessage("**")
   packageStartupMessage("** Version    : ",this.version,"      (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You (kisungyou@outlook.com)")
+  packageStartupMessage("** Maintainer : Kisung You (kisung.you@outlook.com)")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
   packageStartupMessage("** --------------------------------------------------------- **")
